@@ -87,16 +87,16 @@ selection <- function(case,
         B0 <- b / bias_parms[2]
         C0 <- c / bias_parms[3]
         D0 <- d / bias_parms[4]
+
+        tab.corr <- matrix(c(A0, B0, C0, D0), nrow = 2, byrow = TRUE)
+        rr.corr <- (A0/(A0 + C0)) / (B0/(B0 + D0))
+        or.corr <- (A0/B0) / (C0/D0)
     } else {
-        A0 <- a / bias_parms
-        B0 <- b / bias_parms
-        C0 <- c / bias_parms
-        D0 <- d / bias_parms
+        tab.corr <- matrix(c(NA, NA, NA, NA), nrow = 2, byrow = TRUE)
+        rr.corr <- rr / bias_parms
+        or.corr <- or / bias_parms
     }
     
-    tab.corr <- matrix(c(A0, B0, C0, D0), nrow = 2, byrow = TRUE)
-    rr.corr <- (A0/(A0 + C0)) / (B0/(B0 + D0))
-    or.corr <- (A0/B0) / (C0/D0)
    
     if (is.null(rownames(tab)))
         rownames(tab) <- paste("Row", 1:2)
